File name: negot-scen

======================================================================

                     INFORMATION EXTRACTION TASK:  
          DRY-RUN SCENARIO ON LABOR CONTRACT NEGOTIATIONS

                     (Version 1.4, 20 APR 95)


Updates since previous version are indicated by a vertical bar ("|")
in left margin.

======================================================================

                              CONTENTS
1. Narrative
2. Template BNF
3. Fill Rules
3.1 TEMPLATE Object
3.1.1 DOC_NR Slot
3.1.2 CONTENT Slot
3.2 NEGOTIATION Object
3.2.1 PARTY Slot
3.2.2 ISSUE Slot
3.2.3 PROPOSAL_STATUS Slot
3.2.4 TALK_STATUS_1 Slot
3.2.5 TALK_STATUS_2 Slot
3.2.6 DATE_TALK_1 Slot
3.2.7 DATE_TALK_2 Slot
3.3 PARTY Object
3.3.1 NEGOTIATOR_ORG Slot
3.3.2 NEGOTIATOR_SIDE Slot
3.3.3 OFFICIAL Slot
3.3.4 OFFICIAL_ROLE Slot
3.4 ORGANIZATION Object
3.4.1 ORG_NAME Slot
3.4.2 ORG_ALIAS Slot
3.4.3 ORG_DESCRIPTOR Slot
3.4.4 ORG_TYPE Slot
3.4.5 ORG_LOCALE Slot
3.4.6 ORG_COUNTRY Slot
3.4.7 ORG_NATIONALITY Slot
3.5 PERSON Object
3.5.1 PER_NAME Slot
3.5.2 PER_ALIAS Slot
3.5.3 PER_TITLE Slot

======================================================================

1. Narrative

This scenario concerns labor contract negotiations between companies
and the unions to which company employees belong.  The template
captures the parties involved in the negotiation and their
representatives, the status of the negotiations and of the proposal,
and the general nature of the issues addressed by the contract
proposal.  A relevant article refers to an unratified contract and
identifies at least one company or one union involved as party in the
negotiation.


2. Template BNF

<TEMPLATE> :=
	DOC_NR:			"NUMBER"^
	CONTENT:		<NEGOTIATION>*
	COMMENT:		"COMMENT"-

<NEGOTIATION> :=
	PARTY:			<PARTY>+
	ISSUE:			{WAGES, BENEFITS, WORK_RULES,
JOB_SECURITY}*
	PROPOSAL_STATUS:	{PROPOSAL_PRESENTED,
PROPOSAL_REJECTED, TENTATIVE_AGREEMENT, RATIFICATION_FAILED}-
	TALK_STATUS_1:		{POSITIONING, REPOSITIONING,
|BARGAINING, MEDIATION, IMPASSE, PREPARING_FOR_VOTE, VOTING}^
	TALK_STATUS_2:		{POSITIONING, REPOSITIONING,
|BARGAINING, MEDIATION, IMPASSE, PREPARING_FOR_VOTE, VOTING}^
	DATE_TALK_1:		"DATE"*
	DATE_TALK_2:		"DATE"*
	COMMENT:		"COMMENT"-

<PARTY> :=
	NEGOTIATOR_ORG:		<ORGANIZATION> | "GROUP" ^
	NEGOTIATOR_SIDE:	{UNION, EMPLOYER, MEDIATOR}^
	OFFICIAL:		<PERSON>-
	OFFICIAL_ROLE:		"ROLE"-
	COMMENT:		"COMMENT"-

<ORGANIZATION> :=
	ORG_NAME:		"NAME"-
	ORG_ALIAS:		"ALIAS"*
	ORG_DESCRIPTOR:		"DESCRIPTOR"-
	ORG_TYPE:		{GOVERNMENT, COMPANY, OTHER}^
	ORG_LOCALE:		LOCALE-STRING {{LOC_TYPE}} *
	ORG_COUNTRY:		NORMALIZED-COUNTRY | COUNTRY-STRING *
	ORG_NATIONALITY:	NORMALIZED-COUNTRY-or-REGION | COUNTRY-or-REGION-STRING *
	COMMENT:		"COMMENT"-

<PERSON> :=
	PER_NAME:		"NAME"^
	PER_ALIAS:		"ALIAS"*
	PER_TITLE:		"TITLE"*
	COMMENT:		"COMMENT"-



LOC_TYPE ::	{CITY, PROVINCE, COUNTRY, REGION, UNK}

DATE:	    {BEFORE, AFTER, ON} DATE-EXP
	    | BETWEEN DATE-EXP DATE-EXP

DATE-EXP ::	([[01-31]]|{EA, MD, LT, EO, BO})[[01-12]][[00-99]YY]
		| {EA, MD, LT, EO, BO}
		  {FA, WI, SP, SU, 1Q, 2Q, 3Q, 4Q, 1F, 2F, 3F, 4F, FY}
		  [[00-99]YY]
		| {EA, MD, LT, EO, BO, FA, WI, SP, SU, 1Q, 2Q, 3Q, 4Q,
		     1F, 2F, 3F, 4F, FY}
		  [[00-99]YY]
		| [[01-12]][[00-99]YY]
		| [[00-99]] 
		| DESCRIPTOR


3. Fill Rules

Note that each object defined by the template BNF contains a COMMENT
slot.  This slot is reserved for use in the answer-key templates; it
is not to be generated by the extraction systems.  See "Information
Extraction Task Definition" document for further information.

3.1 TEMPLATE Object

  DEFINITION: Top-level object.

  See "Information Extraction Task Definition" for further
information.

3.1.1 DOC_NR Slot

  DEFINITION: Document identifier.  See "Information Extraction Task
Definition" for further information.

3.1.2 CONTENT Slot

  DEFINITION: Pointer to object that captures info on the contract
negotiation process.  See "Information Extraction Task Definition" for
general information.

  MINIMUM INSTANTIATION CONDITIONS: Article must refer to an
unratified contract and identify a company or a union involved as
party in the negotiation.  If contract negotiations have not yet
begun, article must give a definite timeframe for the start of the
negotiations, e.g., "27 March" or "next fall" (but not contingent
timeframes such as "after the company reaches agreement with its other
unions").  If an article makes general reference to an agreement
having been reached, without indicating that the agreement is
unratified, assume that a new contract agreement has been ratified
(the text is therefore not relevant to the scenario).

  SPECIAL USAGE NOTES:
  1. If more than one negotiation is mentioned, e.g., one company
negotiating different contracts with different unions, new NEGOTIATION
objects should be instantiated for each negotiation.  However, if the
article says there is more than one union or more than one company
involved in contract negotiations and does not name the unions or
companies, instantiate just one NEGOTIATION object.

3.2 NEGOTIATION Object

  DEFINITION: The labor contract negotiation process.

  MINIMUM INSTANTIATION CONDITIONS:  See section 3.1.2 above.

3.2.1 PARTY Slot

  DEFINITION: Pointer to object that captures info on 
  1) the organizations currently involved in the contract negotiations
     * on the side of the employer (employer company, parent of employer
company, and/or third-party bargaining agent organization),
     * on the side of the labor union (national union organization, local
union organization, and/or third-party bargaining agent),
     * as formal mediator, and 
  2) any organization officials who represent the organization in the
negotiations or who speak on behalf of the organization.  
  This slot will have at least one value (one employer org or one
union org).  If more than one relevant organization official is
identified in the text, a different PARTY object must be instantiated
for each one.

  MINIMUM INSTANTIATION CONDITIONS: Either (1) the name or description of the
organization must be given or, if the organization is not identified,
(2) the name of a person representing one of the three sides in the
negotiation must be given.

  SPECIAL USAGE NOTES: 
  1. If the only reference to a party is a plural reference,
instantiate just one PARTY object.

3.2.2 ISSUE Slot

  DEFINITION: A general categorization of the issues addressed or to
be addressed by a contract proposal.

  MINIMUM INSTANTIATION CONDITIONS: The issue(s) addressed by
the contract proposal must be identified in general terms, at least.

SPECIAL USAGE NOTES:
  1. The categories that are to be used for this slot are defined as
follows:
     WAGES -- Issues pertaining to employees' pay, e.g., wage
increases/cuts/freezes, wage scales, salaries, bonuses, lump-sum
payments, overtime pay, vacation pay, cost-of-living adjustments.
     BENEFITS -- Issues pertaining to employee benefits, e.g.,
pension, sick leave, vacation, insurance, profit-sharing, severance
package. 
     WORK_RULES -- Issues pertaining to workers' rights and
productivity, e.g., right to strike, right to free agency (for
athletes), grievance systems (including worker protection against
retaliation by employer), amount of overtime, work schedules, length
of work week, length of breaks, crew size, job duties.  Also includes
employer's right to lockouts.
     JOB_SECURITY -- Issues pertaining to job security, e.g., hiring
temporary, part-time or nonunion workers, outsourcing work, worker
replacement practices, layoffs, seniority in layoffs, employment
guarantees, job transfers, policies re plant closings, length of
contract.

3.2.3 PROPOSAL_STATUS Slot

  DEFINITION: The most recent event affecting the status of the
contract proposal.

  MINIMUM INSTANTIATION CONDITIONS:  The article must mention or imply
the most recent event affecting the contract proposal status.  The
|slot will be left blank in cases when bargaining has not yet started
|and a preliminary proposal isn't mentioned.

  SPECIAL USAGE NOTES:
  1. The categories that are to be used for this slot are defined as
follows: 
     PROPOSAL_PRESENTED -- A proposal has been put on the table at the
start of a formal round of contract talks, or a proposal or
counterproposal has been made during a round of formal contract talks,
or a contract offer (including a final take-it-or-leave-it offer) has
been made by the employer during a round of formal contract talks.
     PROPOSAL_REJECTED -- One party in the negotiation has rejected
the proposal or final offer.  If an article indicates that a proposal
is currently in dispute and that the union is taking some retaliatory
action such as a strike or slowdown, it may be assumed that the
proposal was rejected.  Use this fill also when a negotiation involves
proposals on multiple issues and it is reported that one or more were
rejected, even if not all were rejected.
     TENTATIVE_AGREEMENT -- The employer and labor union have reached
tentative agreement on a contract; the agreement must now be ratified
by the union (and maybe also by the employer).
     RATIFICATION_FAILED -- The union or employer failed to ratify the
agreement, by whatever ratification process is required by a particular
union or employer.

3.2.4 TALK_STATUS_1 Slot

 DEFINITION: The current status of talks.  If the article reports
differences of opinion on the current talk status, ignore the opinions
of anyone other than the parties in the negotiation.  If the parties
disagree, use the opinion of the mediator.  If this is not possible
and there is no other way to impartially assess the status, the answer
key will contain alternative fills.

|  MINIMUM INSTANTIATION CONDITIONS: This slot should never be left
|blank.  If the article is vague, the answer key will contain
|alternative acceptable fills.

  SPECIAL USAGE NOTES:
  1. The categories that are to be used for this slot are defined as
follows: 
     POSITIONING -- A definite timeframe (see 3.1.2) for the start of
joint, formal contract negotiations has been announced, but the
negotiations are not yet underway.  If the talks aren't identified as
being unilateral or joint, assume that they are joint.
     REPOSITIONING -- After a breakdown in negotiations, a definite
timeframe for restarting joint, formal talks has been announced, but
the formal talks are not yet underway.
     BARGAINING -- One or more proposals have been presented, and
joint, formal talks are underway without a mediator.  The goal is a
tentative agreement between employer and union.
     MEDIATION -- Formal talks are underway with a mediator.  The goal
is a tentative agreement between employer and union.
     IMPASSE -- Either (1) talks have failed to produce a tentative
agreement, i.e., a proposal was rejected and no new meetings have been
scheduled, or (2) ratification of a tentative agreement failed, and
no new course of action has been agreed to.  "Labor relations" between
employer and union may still exist, i.e., informal talks may be
occurring sporadically during an impasse, but no formal negotiation
sessions.
     PREPARING_FOR_VOTE -- Either (1) a tentative agreement has been
reached, and voting on ratification of the agreement has not yet
started, or (2) a contract offer is being put to a vote of the
union/employer membership without a tentative agreement having been
reached by the negotiators.
     VOTING -- Either (1) the voting on ratification of the agreement
is underway, or (2) the votes are being counted.

3.2.5 TALK_STATUS_2 Slot

 DEFINITION: The next status of talks.  The fill represents what the
next status will definitely be, given the info contained in the
article.  For example, if the parties are currently bargaining and
one side has called for mediation to help the negotiations along, the
TALK_STATUS_2 fill is BARGAINING rather than MEDIATION, since
mediation will not definitely take place unless both the employer and
the union agree to it.

|  MINIMUM INSTANTIATION CONDITIONS: This slot should never be left
|blank.  If the article is vague, the answer key will contain
|alternative acceptable fills.

  SPECIAL USAGE NOTES:  
  1. See 3.2.4 for categories and definitions.
|  2. The fills for TALK_STATUS_1 and TALK_STATUS_2 will generally
|represent a change of status.  For example, the fills may be IMPASSE
|and MEDIATION, if talks are currently stalemated but both sides have
|requested that a federal mediator be brought in.  Or the fills may be
|PREPARING_FOR_VOTE and VOTING, if the parties that must ratify a
|tentative contract agreement are currently getting ready to vote and
|there is a clear indication that a vote will actually be taken.
|     At other time, the fills will represent the continuation of the
same state of affairs.  For example, the fills may be BARGAINING and
BARGAINING, if a bargaining session was just held and if the next
thing that will happen is another bargaining session.  Similarly, the
fills may be IMPASSE and IMPASSE, if talks have reached a stalemate,
i.e., they failed and no new talks are planned.

3.2.6 DATE_TALK_1 Slot

  DEFINITION: Date associated with the current status of talks.  Exact
meaning varies from one value of talk status to another.

|  MINIMUM INSTANTIATION CONDITIONS: Article must give a reference to a
|date or a timeframe associated with the current status of talks, e.g.,
|"on 17 April," "last Monday," "in the last few days."  This slot is
|not to be filled by default.  For example, if the text says only that
|"a tentative agreement was reached," a default fill of "BEFORE <date
|of article>" should not be generated.

  SPECIAL USAGE NOTES:
  1. The fill for this slot reflects the most significant date
associated with certain TALK_STATUS_1 fills, as follows:
     BARGAINING -- The date when the most recent bargaining session
took place, prior to date of article.
     MEDIATION -- The date when the most recent mediated bargaining
session took place, prior to date of article.
     IMPASSE -- The date when formal talks failed, prior to date of
article .
     PREPARING_FOR_VOTE -- The date when tentative agreement on a new
contract was reached, prior to date of article.
     VOTING -- The most recent reported date when votes on
ratification were cast, prior to date of article.  In some cases, both
the employer and the union must vote on the agreement; in such cases,
DATE_TALK_1 may have two values.
     Note that this slot is not applicable when TALK_STATUS_1 is
filled with POSITIONING or REPOSITIONING.
|  2. The fill generated for this slot should constrain the date as
|much as can be inferred from the text.  For example, if the text says
|that "bargaining sessions have been held every day since January 1,"
|and the fill is intended to represent the date of the most recent
|bargaining session, the fill should represent the date prior to the
|date of the article.

3.2.7 DATE_TALK_2 Slot

  DEFINITION: Date associated with the next step in the talks.  Exact
meaning varies from one value of talk status to another.

|  MINIMUM INSTANTIATION CONDITIONS: Article must give a reference to a
|date or a timeframe associated with the next status of talks, e.g.,
|"on 24 April," "next Monday," "in the next few days."  This slot is
|not to be filled by default.  For example, if the text says only that
|"a tentative agreement was reached," a default fill of "BEFORE <date
|of article>" should not be generated.

  SPECIAL USAGE NOTES:
  1. The fill for this slot reflects the most significant date
associated with certain TASK_STATUS_2 fills, as follows:
     BARGAINING -- The date when the next bargaining session is
scheduled to take place, on or after date of article.
     MEDIATION -- The date when the next mediated bargaining session
is scheduled to take place, on or after date of article.
     VOTING -- The date (on or after date of article) when the first
votes on ratification will be cast or, if voting is ongoing, the date
when the next group of voters (such as a particular local union
chapter) will vote.  In some cases, both the employer and the union
must vote on the agreement; in such cases, DATE_TALK_1 may have two
values.
     Note that this slot is not applicable when TALK_STATUS_2 is
filled with POSITIONING, REPOSITIONING, IMPASSE, or PREPARING_FOR_VOTE.
|  2. The fill generated for this slot should constrain the date as
|much as can be inferred from the text.

3.3 PARTY Object

  DEFINITION:  This object captures
  1) the organizations currently involved in the contract negotiations
  * on the side of the employer (employer company, parent of employer
company, and/or third-party bargaining agent organization),
  * on the side of the labor union (national union organization, local
union organization, and/or third-party bargaining agent),
  * as formal mediator, and 
  2) any organization officials who represent the organization in the
negotiations or who speak on behalf of the organization.  

  MINIMUM INSTANTIATION CONDITIONS: See 3.2.1.

3.3.1 NEGOTIATOR_ORG Slot

  DEFINITION: Either (1) pointer to object that captures info on an
individual organization representing employer, labor union, or
mediator in negotiations, or (2) text string describing a group of
(unnamed) organizations.

  MINIMUM INSTANTIATION CONDITIONS: See 3.2.1 above.

3.3.2 NEGOTIATOR_SIDE Slot

  DEFINITION: Identification of which party in the negotiation is
represented by the organization identified in the NEGOTIATOR_ORG slot.

  MINIMUM INSTANTIATION CONDITIONS: The slot must always be filled.

  SPECIAL USAGE NOTES:
  1. The categories that are to be used for this slot are defined as
follows:
     UNION -- The party is involved in the negotiations on the
side of a labor union.
     EMPLOYER -- The party is involved in the negotiations on the
side of an organization that employees members of a labor union.
     MEDIATOR -- The party is involved in the negotiations on the
side of an organization that is designated to serve as mediator in a
contract dispute.

3.3.3 OFFICIAL Slot

  DEFINITION: Pointer to object that captures info on organization
official representing one of the parties in the negotiation or
speaking on behalf of one of the parties.

  MINIMUM INSTANTIATION CONDITIONS: This slot is to be filled only if
an official is named.

3.3.4 OFFICIAL_ROLE Slot

  DEFINITION: The official's role or position with respect to a party
in the negotiation.

  MINIMUM INSTANTIATION CONDITIONS: Text must provide a noun phrase
expressing the person's role/position.

3.4 ORGANIZATION Object

  DEFINITION: An organization that is party to a negotiation.

  MINIMUM INSTANTIATION CONDITIONS: See section 3.2.1 above.

3.4.1 ORG_NAME Slot

  DEFINITION: The name of the organization.

  See "Information Extraction Task Definition" document for further
information.

3.4.2 ORG_ALIAS Slot

  DEFINITION: An alias for an organization.

  See "Information Extraction Task Definition" document for further
information.

3.4.3 ORG_DESCRIPTOR Slot

  DEFINITION: Phrase describing an organization.

  See "Information Extraction Task Definition" document for further
information.

3.4.4 ORG_TYPE Slot

  DEFINITION: The type of organization.

  See "Information Extraction Task Definition" document for further
information.

3.4.5 ORG_LOCALE Slot

  DEFINITION: Location of an organization.

  See "Information Extraction Task Definition" document for further
information.

3.4.6 ORG_COUNTRY Slot

  DEFINITION: Country where organization is located.

  See "Information Extraction Task Definition" document for further
information.

3.4.7 ORG_NATIONALITY Slot

  DEFINITION: The name of the home country or home region of the
organization.

  See "Information Extraction Task Definition" document for further
information.

3.5 PERSON Object

  DEFINITION: A person who is an official representing one of the
parties in the negotiation or speaking on behalf of one of the
parties.

  See "Information Extraction Task Definition" document for further
information.

3.5.1 PER_NAME Slot

  DEFINITION: The name of the person.

  See "Information Extraction Task Definition" document for further
information.

3.5.2 PER_ALIAS Slot

  DEFINITION: Alias for a person.

  See "Information Extraction Task Definition" document for further
information.

3.5.3 PER_TITLE Slot

  DEFINITION: Title of a person.

  See "Information Extraction Task Definition" document for further
information.

